import { ComputedRef, App } from 'vue';
import { SearchOptions as SearchOptions$1 } from 'slimsearch';

type Word = [tag: string, content: string] | string;
interface TitleMatchedItem {
    type: "title";
    id: number;
    display: Word[][];
}
interface HeadingMatchedItem {
    type: "heading";
    id: number;
    anchor: string;
    display: Word[][];
}
interface ContentMatchedItem {
    type: "text";
    id: number;
    header?: string;
    anchor?: string;
    display: Word[][];
}
interface CustomMatchedItem {
    type: "customField";
    id: number;
    index: string;
    display: Word[][];
}
type MatchedItem = TitleMatchedItem | HeadingMatchedItem | ContentMatchedItem | CustomMatchedItem;
interface SearchResult {
    title: string;
    contents: MatchedItem[];
}
interface QueryResult {
    suggestions: string[];
    results: SearchResult[];
}

interface SearchOptions<ID = any, Index extends Record<string, any> = Record<never, never>> extends Omit<SearchOptions$1<ID, Index>, "fields"> {
    locales?: Record<string, Omit<SearchOptions$1<ID, Index>, "fields">>;
}
interface MessageData {
    /**
     * @default "all"
     */
    type?: "search" | "suggest" | "all";
    query: string;
    locale: string;
    options?: SearchOptions;
}

declare const defineSearchConfig: <ID = any, Index extends Record<string, any> = Record<never, never>>(options: SearchOptions<ID, Index>) => void;
declare const useSearchOptions: () => ComputedRef<Omit<SearchOptions, "locales">>;
declare const injectSearchConfig: (app: App) => void;

interface SearchWorker {
    search: <T extends MessageData>(options: T) => Promise<T["type"] extends "search" ? SearchResult[] : T["type"] extends "suggest" ? string[] : QueryResult>;
    terminate: () => void;
}
declare const createSearchWorker: () => SearchWorker;

export { type SearchWorker, createSearchWorker, defineSearchConfig, injectSearchConfig, useSearchOptions };
